@@ -55,7 +55,7 @@
 #include <netdb.h>
 #include <math.h>
 #include <assert.h>
-#ifdef SOLARIS
+#if defined(__sun) && defined(__SVR4)
 #include <sys/sockio.h>
 #ifndef CMSG_SPACE
 #define CMSG_SPACE(len) (_CMSG_HDR_ALIGN(sizeof(struct cmsghdr)) + _CMSG_DATA_ALIGN(len))
@@ -75,48 +75,48 @@
 
 
 #ifdef HAVE_KERNEL_SCTP
-#ifndef HAVE_SCTP_CONNECTX
-#warning No sctp_connectx() available - Using only the first address!
-int sctp_connectx(int                    sockfd,
-                  const struct sockaddr* addrs,
-                  int                    addrcnt,
-                  sctp_assoc_t*          id);
-{
-   const struct sockaddr* bestScopedAddress = getBestScopedAddress(addrs, addrcnt);
-   return(ext_connect(sockfd, bestScopedAddress, getSocklen(bestScopedAddress)));
-}
-#endif
-
-#ifndef HAVE_SCTP_SEND
-#warning No sctp_send() available - Using wrapper!
-ssize_t sctp_send_wrapper(int                           sd,
-                          const void*                   data,
-                          size_t                        len,
-                          const struct sctp_sndrcvinfo* sinfo,
-                          int                           flags)
-{
-   struct sctp_sndrcvinfo* sri;
-   struct iovec            iov = { (char*)data, len };
-   struct cmsghdr*         cmsg;
-   size_t                  cmsglen = CMSG_SPACE(sizeof(struct sctp_sndrcvinfo));
-   char                    cbuf[CMSG_SPACE(sizeof(struct sctp_sndrcvinfo))];
-   struct msghdr msg = {
-      NULL, 0,
-      &iov, 1,
-      cbuf, cmsglen,
-      flags
-   };
-
-   cmsg = (struct cmsghdr*)CMSG_FIRSTHDR(&msg);
-   cmsg->cmsg_len   = CMSG_LEN(sizeof(struct sctp_sndrcvinfo));
-   cmsg->cmsg_level = IPPROTO_SCTP;
-   cmsg->cmsg_type  = SCTP_SNDRCV;
-
-   sri = (struct sctp_sndrcvinfo*)CMSG_DATA(cmsg);
-   memcpy(sri, sinfo, sizeof(struct sctp_sndrcvinfo));
-   return(ext_sendmsg(sd, &msg, msg.msg_flags));
-}
-#endif
+// #ifndef HAVE_SCTP_CONNECTX
+// #warning No sctp_connectx() available - Using only the first address!
+// int sctp_connectx(int                    sockfd,
+//                   const struct sockaddr* addrs,
+//                   int                    addrcnt,
+//                   sctp_assoc_t*          id);
+// {
+//    const struct sockaddr* bestScopedAddress = getBestScopedAddress(addrs, addrcnt);
+//    return(ext_connect(sockfd, bestScopedAddress, getSocklen(bestScopedAddress)));
+// }
+// #endif
+//
+// #ifndef HAVE_SCTP_SEND
+// #warning No sctp_send() available - Using wrapper!
+// ssize_t sctp_send_wrapper(int                           sd,
+//                           const void*                   data,
+//                           size_t                        len,
+//                           const struct sctp_sndrcvinfo* sinfo,
+//                           int                           flags)
+// {
+//    struct sctp_sndrcvinfo* sri;
+//    struct iovec            iov = { (char*)data, len };
+//    struct cmsghdr*         cmsg;
+//    size_t                  cmsglen = CMSG_SPACE(sizeof(struct sctp_sndrcvinfo));
+//    char                    cbuf[CMSG_SPACE(sizeof(struct sctp_sndrcvinfo))];
+//    struct msghdr msg = {
+//       NULL, 0,
+//       &iov, 1,
+//       cbuf, cmsglen,
+//       flags
+//    };
+//
+//    cmsg = (struct cmsghdr*)CMSG_FIRSTHDR(&msg);
+//    cmsg->cmsg_len   = CMSG_LEN(sizeof(struct sctp_sndrcvinfo));
+//    cmsg->cmsg_level = IPPROTO_SCTP;
+//    cmsg->cmsg_type  = SCTP_SNDRCV;
+//
+//    sri = (struct sctp_sndrcvinfo*)CMSG_DATA(cmsg);
+//    memcpy(sri, sinfo, sizeof(struct sctp_sndrcvinfo));
+//    return(ext_sendmsg(sd, &msg, msg.msg_flags));
+// }
+// #endif
 
 #ifndef HAVE_SCTP_SENDX
 #warning No sctp_sendx() available - Using only the first address!
@@ -227,7 +227,7 @@ int ext_poll(struct pollfd* fdlist, long unsigned int count, int time)
 #endif
 
 
-#ifdef LINUX
+#ifdef __linux__
 #define LINUX_PROC_IPV6_FILE "/proc/net/if_inet6"
 #ifdef HAVE_KERNEL_SCTP
 
@@ -253,6 +253,9 @@ enum AddressScopingFlags {
 };
 
 
+#if 0
+/* FIXME: Remove (hopefully) obsolete code! */
+
 /* ###### Filter address ################################################# */
 static bool filterAddress(union sockaddr_union* address,
                           unsigned int          flags)
@@ -329,7 +332,6 @@ static bool obtainLocalAddresses(union sockaddr_union** addressArray,
    }
 
    numAllocAddrs = cf.ifc_len / sizeof(struct ifreq);
-   ifrequest     = cf.ifc_req;
    numIfAddrs    = numAllocAddrs;
 
    addedNets = 0;
@@ -465,6 +467,8 @@ static bool obtainLocalAddresses(union sockaddr_union** addressArray,
 #endif
 #endif
 
+#endif
+
 
 /* ###### Unpack sockaddr blocks to sockaddr_union array ################## */
 union sockaddr_union* unpack_sockaddr(const struct sockaddr* addrArray,
@@ -914,9 +918,9 @@ static unsigned int getScopeIPv4(const uint32_t* address)
 static unsigned int getScopeIPv6(const struct in6_addr* address)
 {
    if(IN6_IS_ADDR_V4MAPPED(address)) {
-#if defined SOLARIS
+#if defined(__sun) && defined(__SVR4)
       return(getScopeIPv4(&address->_S6_un._S6_u32[3]));
-#elif defined LINUX
+#elif defined(__linux__)
       return(getScopeIPv4(&address->s6_addr32[3]));
 #else
       return(getScopeIPv4(&address->__u6_addr.__u6_addr32[3]));
@@ -1412,7 +1416,7 @@ int sendtoplus(int                      sockfd,
                           (struct sockaddr*)toaddrs,
                           (toaddrs != NULL) ? getSocklen((struct sockaddr*)toaddrs) : 0);
    }
-#ifdef LINUX
+#ifdef __linux__
 #warning Using lksctp SCTP_EOF/SCTP_ABORT shutdown work-around for TCP-like sockets!
    /* LK-SCTP refuses SCTP_EOF and SCTP_ABORT on TCP-like socket.
       => using ext_shutdown() instead! */
@@ -1820,7 +1824,7 @@ bool setReusable(int sd, int on)
    if(ext_setsockopt(sd, SOL_SOCKET, SO_REUSEADDR, &on, sizeof(on)) != 0) {
       return(false);
    }
-#if !defined (LINUX) && !defined (SOLARIS)
+#if !defined (__linux__) && !(defined(__sun) && defined(__SVR4))
    if(ext_setsockopt(sd, SOL_SOCKET, SO_REUSEPORT, &on, sizeof(on)) != 0) {
       return(false);
    }
@@ -1855,12 +1859,15 @@ size_t getladdrsplus(const int              fd,
                      union sockaddr_union** addressArray)
 {
    struct sockaddr* packedAddresses = NULL;
-#ifdef SOLARIS
-   int addrs = sctp_getladdrs(fd, assocID, (void**)&packedAddresses);
+#if defined(__sun) && defined(__SVR4)
+   int              addrs = sctp_getladdrs(fd, assocID, (void**)&packedAddresses);
 #else
-   int addrs = sctp_getladdrs(fd, assocID, &packedAddresses);
+   int              addrs = sctp_getladdrs(fd, assocID, &packedAddresses);
 #endif
-#ifdef LINUX
+   int              i;
+#if 0
+/* FIXME: Remove (hopefully) obsolete code! */
+#ifdef __linux__
 #ifdef HAVE_KERNEL_SCTP
    union sockaddr_union socketName;
    socklen_t            socketNameLen;
@@ -1869,10 +1876,26 @@ size_t getladdrsplus(const int              fd,
    size_t               j;
 #endif
 #endif
-   int i;
+#endif
 
    if(addrs > 0) {
-#ifdef LINUX
+#ifdef HAVE_VALGRIND_MEMCHECK_H
+      struct sockaddr* a = packedAddresses;
+      for(i = 0;i < addrs;i++) {
+         if(a->sa_family == AF_INET) {
+            VALGRIND_MAKE_MEM_DEFINED(a, sizeof(struct sockaddr_in));
+            a = (struct sockaddr*)((long)a + (long)sizeof(struct sockaddr_in));
+         }
+         else if(a->sa_family == AF_INET6) {
+            VALGRIND_MAKE_MEM_DEFINED(a, sizeof(struct sockaddr_in6));
+            a = (struct sockaddr*)((long)a + (long)sizeof(struct sockaddr_in6));
+         }
+      }
+#endif
+
+#if 0
+/* FIXME: Remove (hopefully) obsolete code! */
+#ifdef __linux__
 #ifdef HAVE_KERNEL_SCTP
 #warning Using sctp_getladdrs() INADDR_ANY bugfix for lksctp!
       if((addrs == 1) &&
@@ -1896,10 +1919,14 @@ size_t getladdrsplus(const int              fd,
       }
 #endif
 #endif
+#endif
+
       *addressArray = unpack_sockaddr(packedAddresses, addrs);
       sctp_freeladdrs(packedAddresses);
 
-#ifdef LINUX
+#if 0
+/* FIXME: Remove (hopefully) obsolete code! */
+#ifdef __linux__
 #ifdef HAVE_KERNEL_SCTP
 #warning Using sctp_getladdrs() port 0 bugfix for lksctp!
       if(getPort(&(*addressArray)[0].sa) == 0) {
@@ -1912,6 +1939,7 @@ size_t getladdrsplus(const int              fd,
          }
       }
 #endif
+#endif
 #endif
 
       LOG_VERBOSE5
@@ -1941,7 +1969,7 @@ size_t getpaddrsplus(const int              fd,
                      union sockaddr_union** addressArray)
 {
    struct sockaddr* packedAddresses = NULL;
-#ifdef SOLARIS
+#if defined(__sun) && defined(__SVR4)
    int addrs = sctp_getpaddrs(fd, assocID, (void **)&packedAddresses);
 #else
    int addrs = sctp_getpaddrs(fd, assocID, &packedAddresses);
@@ -1958,7 +1986,7 @@ size_t getpaddrsplus(const int              fd,
 /* ###### Send SCTP ABORT ################################################ */
 int sendabort(int sockfd, sctp_assoc_t assocID)
 {
-#ifdef SOLARIS
+#if defined(__sun) && defined(__SVR4)
    /* The Solaris API has no SCTP_ABORT. Instead, it is a regular flag. */
    return(sendtoplus(sockfd, NULL, 0,
                      MSG_ABORT,
@@ -1984,7 +2012,7 @@ int sendshutdown(int sockfd, sctp_assoc_t assocID)
       /* FreeBSD seems to ignore SCTP_EOF on TCP-like socket! */
       return(ext_shutdown(sockfd, 2));
    }
-#ifdef SOLARIS
+#if defined(__sun) && defined(__SVR4)
    /* The Solaris API has no SCTP_ABORT. Instead, it is a regular flag. */
    return(sendtoplus(sockfd, NULL, 0,
                      MSG_EOF,
