@@ -8,7 +8,7 @@
  *
  * ------------- An Efficient RSerPool Prototype Implementation -------------
  *
- * Copyright (C) 2002-2020 by Thomas Dreibholz
+ * Copyright (C) 2002-2021 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -201,6 +201,7 @@ struct rserpool_policy_priority_leastused
 {
    uint32_t pp_plu_policy;
    uint32_t pp_plu_load;
+   uint32_t pp_plu_loaddeg;
 } __attribute__((packed));
 
 struct rserpool_policy_priority_leastused_degradation
@@ -246,6 +247,7 @@ struct rserpool_policy_randomized_priority_leastused
 {
    uint32_t pp_rplu_policy;
    uint32_t pp_rplu_load;
+   uint32_t pp_rplu_loaddeg;
 } __attribute__((packed));
 
 struct rserpool_policy_randomized_priority_leastused_degradation
