@@ -181,9 +181,9 @@ static bool createAddressParameter(struct RSerPoolMessage* message,
              if(output == NULL) {
                 return(false);
              }
-#if defined SOLARIS
+#if defined(__sun) && defined(__SVR4)
              memcpy(output, &in6->sin6_addr._S6_un._S6_u32[3], 4);
-#elif defined LINUX
+#elif defined(__linux__)
              memcpy(output, &in6->sin6_addr.s6_addr32[3], 4);
 #else
              memcpy(output, &in6->sin6_addr.__u6_addr.__u6_addr32[3], 4);
@@ -627,7 +627,9 @@ static bool createErrorParameter(struct RSerPoolMessage* message)
 
    aec->aec_cause  = htons(cause);
    aec->aec_length = htons(sizeof(struct rserpool_errorcause) + dataLength);
-   memcpy((char*)&aec->aec_data, data, dataLength);
+   if(dataLength > 0) {
+      memcpy((char*)&aec->aec_data, data, dataLength);
+   }
 
    return(finishTLV(message, tlvPosition));
 }
