@@ -8,7 +8,7 @@
  *
  * ------------- An Efficient RSerPool Prototype Implementation -------------
  *
- * Copyright (C) 2002-2020 by Thomas Dreibholz
+ * Copyright (C) 2002-2021 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -675,11 +675,14 @@ static bool scanPolicyParameter(struct RSerPoolMessage*    message,
                message->Error = RSPERR_INVALID_VALUE;
                return(false);
             }
-            poolPolicySettings->PolicyType = ntohl(plu->pp_plu_policy);
-            poolPolicySettings->Weight     = 0;
-            poolPolicySettings->Load       = ntohl(plu->pp_plu_load);
+            poolPolicySettings->PolicyType      = ntohl(plu->pp_plu_policy);
+            poolPolicySettings->Weight          = 0;
+            poolPolicySettings->Load            = ntohl(plu->pp_plu_load);
+            poolPolicySettings->LoadDegradation = ntohl(plu->pp_plu_loaddeg);
             LOG_VERBOSE3
-            fprintf(stdlog, "Scanned policy PLU, load=$%06x\n",poolPolicySettings->Load);
+            fprintf(stdlog, "Scanned policy PLU, load=$%06x loaddeg=$%06x\n",
+                    poolPolicySettings->Load,
+                    poolPolicySettings->LoadDegradation);
             LOG_END
          }
          else {
@@ -907,11 +910,14 @@ static bool scanPolicyParameter(struct RSerPoolMessage*    message,
             if(rplu == NULL) {
                return(false);
             }
-            poolPolicySettings->PolicyType = ntohl(rplu->pp_rplu_policy);
-            poolPolicySettings->Weight     = 0;
-            poolPolicySettings->Load       = ntohl(rplu->pp_rplu_load);
+            poolPolicySettings->PolicyType      = ntohl(rplu->pp_rplu_policy);
+            poolPolicySettings->Weight          = 0;
+            poolPolicySettings->Load            = ntohl(rplu->pp_rplu_load);
+            poolPolicySettings->LoadDegradation = ntohl(rplu->pp_rplu_loaddeg);
             LOG_VERBOSE3
-            fprintf(stdlog, "Scanned policy PLU, load=$%06x\n",poolPolicySettings->Load);
+            fprintf(stdlog, "Scanned policy RPLU, load=$%06x loaddeg=$%06x\n",
+                    poolPolicySettings->Load,
+                    poolPolicySettings->LoadDegradation);
             LOG_END
          }
          else {
